# DINO hub seedwork

This is a package contains
  * DDD (Domain Driven Design) artifact
  * Functional programming with Returns
  * Basic helpers function

## Install

`dinohub-seedwork-be` is available on PyPi:

```
pip install dinohub-seedwork-be
```

See at here: https://pypi.org/project/dinohub-seedwork-be/
